import pandas as pd

from ._krx import get_json_data


class KrxStock:
    def __init__(self, date, market='ALL', share='1', money='1'):
        self.date = date.strftime('%Y%m%d')
        self.market = market  # 'ALL': 전체, 'STK': KOSPI, 'KSQ': KOSDAQ, 'KNX': KONEX
        self.share = share  # '1':주, '2':천주, '3':백만주
        self.money = money  # '1':원, '2':천원, '3':백만원, '4':십억원

        self.locale = 'ko_KR'
        self.csvxls_is_no = 'false'

    @staticmethod
    def get_output(params):
        dic = get_json_data(params)

        return pd.DataFrame(dic['OutBlock_1'])

    def s12001(self):
        """[12001] 전종목 시세
        :return:
        """
        bld = 'dbms/MDC/STAT/standard/MDCSTAT01501'

        params = {
            'bld': bld,
            'locale': self.locale,
            'mktId': self.market,
            'trdDd': self.date,
            'share': self.share,
            'money': self.money,
            'csvxls_isNo': self.csvxls_is_no
        }
        df = self.get_output(params)

        return df

    def s12005(self):
        """[12005] 전종목 기본정보
        :return:
        """
        bld = 'dbms/MDC/STAT/standard/MDCSTAT01901'

        params = {
            'bld': bld,
            'locale': self.locale,
            'mktId': self.market,
            'share': self.share,
            'csvxls_isNo': self.csvxls_is_no
        }
        df = self.get_output(params)

        return df



import pandas as pd

from ._krx import get_json_data


class KrxIndex:
    def __init__(self, date, sector='01', share='2', money='3'):
        self.date = date.strftime('%Y%m%d')
        self.sector = sector  # '01': KRX, '02': KOSPI, '03': KOSDAQ, '04': 테마
        self.share = share  # '1':주, '2':천주, '3':백만주
        self.money = money  # '1':원, '2':천원, '3':백만원, '4':십억원

        self.locale = 'ko_KR'
        self.csvxls_is_no = 'false'

    @staticmethod
    def get_output(params):
        # params['name'] = 'fileDown'
        # params['url'] = params['bld']
        # del params['bld']
        # csv = download_csv(params)
        # return pd.read_csv(csv, encoding='utf-8')

        dic = get_json_data(params)

        return pd.DataFrame(dic['output'])

    def s11001(self):
        """[11001] 전체지수 시세
        :return:
        """
        bld = 'dbms/MDC/STAT/standard/MDCSTAT00101'

        params = {
            'bld': bld,
            'locale': self.locale,
            'idxIndMidclssCd': self.sector,
            'trdDd': self.date,
            'share': self.share,
            'money': self.money,
            'csvxls_isNo': self.csvxls_is_no
        }
        df = self.get_output(params)

        return df

    def s11002(self, start_date):
        """[11002] 전체지수 등락률
        :return:
        """
        bld = 'dbms/MDC/STAT/standard/MDCSTAT00201'

        params = {
            'bld': bld,
            'locale': self.locale,
            'idxIndMidclssCd': self.sector,
            'strtDd': start_date,
            'endDd': self.date,
            'share': self.share,
            'money': self.money,
            'csvxls_isNo': self.csvxls_is_no
        }
        df = self.get_output(params)

        return df



import requests


def get_json_data(data):
    url = 'http://data.krx.co.kr/comm/bldAttendant/getJsonData.cmd'

    r = requests.post(url=url, data=data)
    dic = r.json()

    return dic


def download_csv(data):
    # 1. Generate OTP
    generate_url = 'http://data.krx.co.kr/comm/fileDn/GenerateOTP/generate.cmd'

    r = requests.post(url=generate_url, data=data)
    otp = {
        'code': r.text
    }

    # 2. Download CSV
    download_url = 'http://data.krx.co.kr/comm/fileDn/download_csv/download.cmd'

    r = requests.post(url=download_url, data=otp)
    csv = r.content.decode(encoding='euc_kr')

    return csv


if __name__ == '__main__':
    params = {
        'bld': 'dbms/MDC/STAT/standard/MDCSTAT00101',
        'locale': 'ko_KR',
        'idxIndMidclssCd': '01',
        'trdDd': '20220822',
        'share': '2',
        'money': '3',
        'csvxls_isNo': 'false'
    }

    d = get_json_data(params)

    print('=======================================')
    print(type(d))
    print(d)

    params['name'] = 'fileDown'
    params['url'] = params['bld']
    del params['bld']

    c = download_csv(params)

    print('=======================================')
    print(type(c))
    print(c)



from datetime import datetime, timezone, timedelta


def today():
    return datetime.now(tz=timezone(timedelta(hours=9))).date()


def is_weekend(date):
    week = date.weekday()

    if week == 5 or week == 6:
        return True
    else:
        return False


def is_holiday(date):
    """
    NotImplemented
    """
    return False


def is_trading_day(date):
    if is_weekend(date) or is_holiday(date):
        return False
    else:
        return True


if __name__ == '__main__':
    today = today()
    print(today)

    if is_trading_day(today):
        print('trading day')
    else:
        print('closing day')
